==> openfire_src_3_4_1.tar.gz: openfire_src/src/plugins/gateway/src/database/gateway_sqlserver.sql <==
CREATE TABLE gatewayRegistration (
   registrationID    BIGINT          NOT NULL,
   jid               NVARCHAR(255)   NOT NULL,
   transportType     NVARCHAR(15)    NOT NULL,
   username          NVARCHAR(255)   NOT NULL,
   password          NVARCHAR(255),
   nickname          NVARCHAR(255),
   registrationDate  BIGINT          NOT NULL,
   lastLogin         BIGINT,
   CONSTRAINT gatewayReg_pk PRIMARY KEY (registrationID)
);
CREATE INDEX gatewayReg_jid_idx ON gatewayRegistration (jid);
CREATE INDEX gatewayReg_type_idx ON gatewayRegistration (transportType);

CREATE TABLE gatewayPseudoRoster (
   registrationID    BIGINT         NOT NULL,
   username          NVARCHAR(255)  NOT NULL,
   nickname          NVARCHAR(255),
   groups            NVARCHAR(255)
);
CREATE INDEX gatewayPsRs_regid_idx ON gatewayPseudoRoster (registrationID);
CREATE INDEX gatewayPsRs_uname_idx ON gatewayPseudoRoster (username);

CREATE TABLE gatewayRestrictions (
   transportType     NVARCHAR(15)  NOT NULL,
   username          NVARCHAR(255),
   groupname         NVARCHAR(50)
);
CREATE INDEX gatewayRstr_ttype_idx ON gatewayRestrictions (transportType);
CREATE INDEX gatewayRstr_uname_idx ON gatewayRestrictions (username);

CREATE TABLE gatewayAvatars (
   jid               NVARCHAR(255)  NOT NULL,
   imageData         NTEXT          NOT NULL,
   xmppHash          NVARCHAR(255),
   legacyIdentifier  NVARCHAR(255),
   createDate        BIGINT         NOT NULL,
   lastUpdate        BIGINT
);
CREATE INDEX gatewayAvtr_jid_idx ON gatewayAvatars (jid);

CREATE TABLE gatewayVCards (
   jid               NVARCHAR(255)  NOT NULL,
   value             NTEXT          NOT NULL
);
CREATE INDEX gatewayVCrd_jid_idx ON gatewayVCards (jid);

INSERT INTO jiveVersion (name, version) VALUES ('gateway', 4);

==> openfire_src_3_4_2.tar.gz: openfire_src/src/plugins/gateway/src/database/gateway_sqlserver.sql <==
CREATE TABLE gatewayRegistration (
   registrationID    BIGINT          NOT NULL,
   jid               NVARCHAR(255)   NOT NULL,
   transportType     NVARCHAR(15)    NOT NULL,
   username          NVARCHAR(255)   NOT NULL,
   password          NVARCHAR(255),
   nickname          NVARCHAR(255),
   registrationDate  BIGINT          NOT NULL,
   lastLogin         BIGINT,
   CONSTRAINT gatewayReg_pk PRIMARY KEY (registrationID)
);
CREATE INDEX gatewayReg_jid_idx ON gatewayRegistration (jid);
CREATE INDEX gatewayReg_type_idx ON gatewayRegistration (transportType);

CREATE TABLE gatewayPseudoRoster (
   registrationID    BIGINT         NOT NULL,
   username          NVARCHAR(255)  NOT NULL,
   nickname          NVARCHAR(255),
   groups            NVARCHAR(255)
);
CREATE INDEX gatewayPsRs_regid_idx ON gatewayPseudoRoster (registrationID);
CREATE INDEX gatewayPsRs_uname_idx ON gatewayPseudoRoster (username);

CREATE TABLE gatewayRestrictions (
   transportType     NVARCHAR(15)  NOT NULL,
   username          NVARCHAR(255),
   groupname         NVARCHAR(50)
);
CREATE INDEX gatewayRstr_ttype_idx ON gatewayRestrictions (transportType);
CREATE INDEX gatewayRstr_uname_idx ON gatewayRestrictions (username);

CREATE TABLE gatewayAvatars (
   jid               NVARCHAR(255)  NOT NULL,
   imageData         NTEXT          NOT NULL,
   xmppHash          NVARCHAR(255),
   legacyIdentifier  NVARCHAR(255),
   createDate        BIGINT         NOT NULL,
   lastUpdate        BIGINT,
   imageType         NVARCHAR(25)
);
CREATE INDEX gatewayAvtr_jid_idx ON gatewayAvatars (jid);

CREATE TABLE gatewayVCards (
   jid               NVARCHAR(255)  NOT NULL,
   value             NTEXT          NOT NULL
);
CREATE INDEX gatewayVCrd_jid_idx ON gatewayVCards (jid);

INSERT INTO jiveVersion (name, version) VALUES ('gateway', 5);
